Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4581)

Unified Diff: chrome/browser/cocoa/toolbar_controller.h

Issue 149308: a bunch of bookmark bar changes (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/toolbar_controller.h
===================================================================
--- chrome/browser/cocoa/toolbar_controller.h (revision 20198)
+++ chrome/browser/cocoa/toolbar_controller.h (working copy)
@@ -10,8 +10,10 @@
#include "base/scoped_ptr.h"
#include "base/scoped_nsobject.h"
#import "chrome/browser/cocoa/command_observer_bridge.h"
+#import "chrome/browser/cocoa/bookmark_bar_controller.h"
#include "chrome/common/pref_member.h"
+@class BookmarkBarView;
class CommandUpdater;
class LocationBar;
class LocationBarViewMac;
@@ -32,8 +34,10 @@
- (void)performCut:(NSPasteboard*)pb;
@end
// A controller for the toolbar in the browser window. Manages updating the
// state for location bar and back/fwd/reload/go buttons.
@interface ToolbarController : NSViewController<CommandObserverProtocol> {
@private
@@ -43,6 +47,9 @@
scoped_ptr<CommandObserverBridge> commandObserver_;
scoped_ptr<LocationBarViewMac> locationBarView_;
scoped_nsobject<LocationBarFieldEditor> locationBarFieldEditor_; // strong
+ scoped_nsobject<BookmarkBarController> bookmarkBarController_;
+ id<BookmarkURLOpener> bookmarkBarDelegate_; // weak
+ NSView* webContentView_; // weak; where the web goes
// Used for monitoring the optional toolbar button prefs.
scoped_ptr<ToolbarControllerInternal::PrefObserverBridge> prefObserver_;
@@ -64,13 +71,16 @@
IBOutlet NSButton* pageButton_;
IBOutlet NSButton* wrenchButton_;
IBOutlet NSTextField* locationBar_;
+ IBOutlet BookmarkBarView* bookmarkBarView_;
}
// Initialize the toolbar and register for command updates. The profile is
// needed for initializing the location bar.
- (id)initWithModel:(ToolbarModel*)model
commands:(CommandUpdater*)commands
- profile:(Profile*)profile;
+ profile:(Profile*)profile
+ webContentView:(NSView*)webContentView
+ bookmarkDelegate:(id<BookmarkURLOpener>)delegate;
// Get the C++ bridge object representing the location bar for this tab.
- (LocationBar*)locationBar;
@@ -98,6 +108,9 @@
// state.
- (void)setIsLoading:(BOOL)isLoading;
+// Return the bookmark bar controller.
+- (BookmarkBarController*)bookmarkBarController;
+
// Actions for the optional menu buttons for the page and wrench menus. These
// will show a menu while the mouse is down.
- (IBAction)showPageMenu:(id)sender;

Powered by Google App Engine
This is Rietveld 408576698
@@ -32,8 +34,10 @@
-// A controller for the toolbar in the browser window. Manages updating the
-// state for location bar and back/fwd/reload/go buttons.
+// A controller for the toolbar in the browser window. Manages
+// updating the state for location bar and back/fwd/reload/go buttons.
+// Manages the bookmark bar and it's position in the window relative to
+// the web content view.